IF OBJECT_ID('[Environments_LatestDeployedReleases]') IS NOT NULL DROP VIEW [Environments_LatestDeployedReleases]
GO

IF OBJECT_ID('[Applications_LatestDeployedReleases]') IS NOT NULL DROP VIEW [Applications_LatestDeployedReleases]
GO

CREATE VIEW [Applications_LatestDeployedReleases] AS

SELECT A.[Application_Id]
	  ,A.[ApplicationGroup_Id]
	  ,A.[Application_Name]
	  ,AG.[ApplicationGroup_Name]
	  ,BP.[Promotion_Id]
	  ,BP.[PipelineStage_Name]
	  ,R.[Release_Id]
	  ,R.[Release_Number]
	  ,[Release_Name] = COALESCE(R.[Release_Name], R.[Release_Number])
	  ,B.[Build_Id]
	  ,B.[Build_Number]
	  ,BE.[Execution_Id]
      ,[ExecutionStart_Date] = X.[Start_Date]
	  ,X.[ExecutionStatus_Code]
	  ,X.[ExecutionRunState_Code]

  FROM (SELECT [Build_Id],
               [Release_Id],
			   [Build_Number]
		  FROM [Builds]
		 WHERE [BuildStatus_Name] = 'Active') B

	   INNER JOIN [Releases] R
	           ON R.[Release_Id] = B.[Release_Id]

	   INNER JOIN [Applications] A
	           ON A.[Application_Id] = R.[Application_Id]

		LEFT JOIN [ApplicationGroups] AG
		       ON AG.[ApplicationGroup_Id] = A.[ApplicationGroup_Id]

	   INNER JOIN [BuildPromotions] BP
	           ON BP.[Build_Id] = B.[Build_Id]

       INNER JOIN (SELECT [Promotion_Id],
	                      [Execution_Id] = MAX([Execution_Id])
	                 FROM [PipelineStageTargetExecutions] _BE
					GROUP BY _BE.[Promotion_Id]) BE
			   ON BE.[Promotion_Id] = BP.[Promotion_Id]

	   INNER JOIN [Executions] X
	           ON X.[Execution_Id] = BE.[Execution_Id]

 WHERE A.[Active_Indicator] = 'Y'
   AND R.[ReleaseStatus_Name] <> 'Cancelled'

GO