EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'DatabaseChangeScripts_ImportChangeScript',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Script_Id',
    /* Description_Text        */ 'Imports a database change script.'
GO

IF OBJECT_ID('[DatabaseChangeScripts_ImportChangeScript]') IS NOT NULL DROP PROCEDURE [DatabaseChangeScripts_ImportChangeScript]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [DatabaseChangeScripts_ImportChangeScript]
(
	@Deployable_Id INT,
	@Script_Name NVARCHAR(250),
	@Script_Text NVARCHAR(MAX),
	@Active_Indicator YNINDICATOR,
	@CreatedBy_User_Name USERNAME,
	@CreatedOn_Date DATETIME,
	@ModifiedBy_User_Name USERNAME,
	@ModifiedOn_Date DATETIME,
	@Script_Guid UNIQUEIDENTIFIER,
	@Release_Id INT,
	@Script_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	INSERT INTO [DatabaseChangeScripts]
	(
		[Deployable_Id],
		[Script_Name],
		[Script_Text],
		[Active_Indicator],
		[CreatedBy_User_Name],
		[CreatedOn_Date],
		[ModifiedBy_User_Name],
		[ModifiedOn_Date],
		[Script_Guid],
		[Release_Id]
	)
	VALUES
	(
		@Deployable_Id,
		@Script_Name,
		@Script_Text,
		@Active_Indicator,
		@CreatedBy_User_Name,
		@CreatedOn_Date,
		@ModifiedBy_User_Name,
		@ModifiedOn_Date,
		@Script_Guid,
		@Release_Id
	)

	SET @Script_Id = SCOPE_IDENTITY()

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DatabaseChangeScripts_ImportChangeScript] TO [BuildMasterUser_Role]
