EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Releases_CreateOrUpdateReleaseNote',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ReleaseNote_Sequence',
    /* Description_Text        */ 'Creates a new release note, or updates an existing one.'
GO

IF OBJECT_ID('[Releases_CreateOrUpdateReleaseNote]') IS NOT NULL DROP PROCEDURE [Releases_CreateOrUpdateReleaseNote]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Releases_CreateOrUpdateReleaseNote]
(
	@Release_Id INT,
	@Notes_Text VARCHAR(MAX),
	@Build_Id INT = NULL,
	@ReleaseNote_Sequence INT = NULL OUT
) 
AS BEGIN

SET NOCOUNT ON

BEGIN TRY

	BEGIN TRANSACTION

	IF @ReleaseNote_Sequence IS NOT NULL

		UPDATE [ReleaseNotes]
		   SET [Notes_Text] = @Notes_Text
		      ,[ModifiedBy_User_Name] = dbo.Session_GetUserName()
		      ,[ModifiedOn_Date] = GETUTCDATE()
			  ,[Build_Id] = @Build_Id
		 WHERE [Release_Id] = @Release_Id
		   AND [ReleaseNote_Sequence] = @ReleaseNote_Sequence
	
	ELSE BEGIN

		SET @ReleaseNote_Sequence = COALESCE(
		            (SELECT MAX([ReleaseNote_Sequence]) + 1
		               FROM [ReleaseNotes]
		              WHERE [Release_Id] = @Release_Id), 1)

		INSERT INTO [ReleaseNotes]
		(
			[Release_Id],
			[ReleaseNote_Sequence],
			[Build_Id],
			[Notes_Text],
			[CreatedBy_User_Name],
			[CreatedOn_Date],
			[ModifiedBy_User_Name],
			[ModifiedOn_Date]
		)
		VALUES
		(
			@Release_Id,
			@ReleaseNote_Sequence,
			@Build_Id,
			@Notes_Text,
			dbo.Session_GetUserName(),
			GETUTCDATE(),
			dbo.Session_GetUserName(),
			GETUTCDATE()
		)
	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0  ROLLBACK
	EXEC [HandleError]
END CATCH
		 

END
GO

GRANT EXECUTE ON [Releases_CreateOrUpdateReleaseNote] TO [BuildMasterUser_Role]
