EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'RetentionPolicies_GetBuildsWithLogsToPurge',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'Builds_Extended',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets only the builds that have logs remaining for the specified retention policy that can be purged.'
GO

IF OBJECT_ID('[RetentionPolicies_GetBuildsWithLogsToPurge]') IS NOT NULL DROP PROCEDURE [RetentionPolicies_GetBuildsWithLogsToPurge]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [RetentionPolicies_GetBuildsWithLogsToPurge]
(
	@RetentionPolicy_Id INT
)
AS
BEGIN

	SET NOCOUNT ON

    DECLARE @BuildsMatchingFilter_Count INT
    DECLARE @BuildsToDelete_Count INT
	DECLARE @DeployedReleasesOnly_Indicator YNINDICATOR
    DECLARE @RejectedOnly_Indicator YNINDICATOR
    DECLARE @Retention_Count INT
    DECLARE @AlwaysRetainAfter_Date DATETIME
	DECLARE @Application_Id INT
	DECLARE @ApplicationGroup_Id INT
    DECLARE @Pipeline_Name VARCHAR(100)
    
    SELECT @DeployedReleasesOnly_Indicator = [PurgeIn_OnlyDeployedReleases_Indicator],
           @RejectedOnly_Indicator = [PurgeIn_OnlyRejectedBuilds_Indicator],
           @Retention_Count = [Retention_Count],
           @Application_Id = [PurgeIn_Application_Id],
           @ApplicationGroup_Id = [PurgeIn_ApplicationGroup_Id],
           @Pipeline_Name = [PurgeIn_Pipeline_Name],
           @AlwaysRetainAfter_Date = DATEADD(DAY, -1 * [Retention_Days_Count], GETUTCDATE())
      FROM [RetentionPolicies]
     WHERE [RetentionPolicy_Id] = @RetentionPolicy_Id

    IF @ApplicationGroup_Id IS NOT NULL
	BEGIN

        IF @Retention_Count IS NOT NULL
        BEGIN        
        
            SELECT @BuildsMatchingFilter_Count = COUNT(*) 
                         FROM [Builds_Extended] B
		           INNER JOIN [Applications] A
			               ON A.[Application_Id] = B.[Application_Id]
		                WHERE A.[ApplicationGroup_Id] = @ApplicationGroup_Id
                          AND (@Pipeline_Name IS NULL OR B.[Pipeline_Name] = @Pipeline_Name)
		                  AND (@DeployedReleasesOnly_Indicator = 'N' OR [ReleaseStatus_Name] = 'Deployed')
		                  AND (@RejectedOnly_Indicator = 'N' OR [BuildStatus_Name] = 'Rejected')
                          AND EXISTS(
						        SELECT TOP 1 SEL.[Scope_Sequence]
								  FROM [BuildExecutions_Extended] BEX
							INNER JOIN [ScopedExecutionLogs] SEL
							        ON SEL.[Execution_Id] = BEX.[Execution_Id]
                                 WHERE B.[Build_Id] = BEX.[Build_Id]
                          )

            SET @BuildsToDelete_Count = @BuildsMatchingFilter_Count - @Retention_Count
        
            IF (@BuildsToDelete_Count < 1)
                RETURN

            SET ROWCOUNT @BuildsToDelete_Count

        END

		SELECT B.*
		  FROM [Builds_Extended] B
		       INNER JOIN [Applications] A
			           ON A.[Application_Id] = B.[Application_Id]
		 WHERE A.[ApplicationGroup_Id] = @ApplicationGroup_Id
           AND (@Pipeline_Name IS NULL OR B.[Pipeline_Name] = @Pipeline_Name)
		   AND (@DeployedReleasesOnly_Indicator = 'N' OR [ReleaseStatus_Name] = 'Deployed')
		   AND (@RejectedOnly_Indicator = 'N' OR [BuildStatus_Name] = 'Rejected')
		   AND (@AlwaysRetainAfter_Date IS NULL OR B.[CreatedOn_Date] < @AlwaysRetainAfter_Date)
           AND EXISTS(
		        SELECT TOP 1 SEL.[Scope_Sequence]
				  FROM [BuildExecutions_Extended] BEX
			INNER JOIN [ScopedExecutionLogs] SEL
			        ON SEL.[Execution_Id] = BEX.[Execution_Id]
                             WHERE B.[Application_Id] = BEX.[Application_Id]
                               AND B.[Release_Number] = BEX.[Release_Number]
                               AND B.[Build_Number] = BEX.[Build_Number]
            )
		 ORDER BY [CreatedOn_Date]

	END
	ELSE
	BEGIN

        IF @Retention_Count IS NOT NULL
        BEGIN        
        
            SELECT @BuildsMatchingFilter_Count = COUNT(*) 
                         FROM [Builds_Extended] BE
		                WHERE (@Application_Id IS NULL OR [Application_Id] = @Application_Id)
                          AND (@Pipeline_Name IS NULL OR [Pipeline_Name] = @Pipeline_Name)
		                  AND (@DeployedReleasesOnly_Indicator = 'N' OR [ReleaseStatus_Name] = 'Deployed')
		                  AND (@RejectedOnly_Indicator = 'N' OR [BuildStatus_Name] = 'Rejected')
                          AND EXISTS(
						        SELECT TOP 1 SEL.[Scope_Sequence]
								  FROM [BuildExecutions_Extended] BEX
							INNER JOIN [ScopedExecutionLogs] SEL
							        ON SEL.[Execution_Id] = BEX.[Execution_Id]
                                 WHERE BE.[Build_Id] = BEX.[Build_Id]
                          ) 

            SET @BuildsToDelete_Count = @BuildsMatchingFilter_Count - @Retention_Count
        
            IF (@BuildsToDelete_Count < 1)
                RETURN

            SET ROWCOUNT @BuildsToDelete_Count

        END

		SELECT *
		  FROM [Builds_Extended] B
		 WHERE (@Application_Id IS NULL OR [Application_Id] = @Application_Id)
           AND (@Pipeline_Name IS NULL OR [Pipeline_Name] = @Pipeline_Name)
		   AND (@DeployedReleasesOnly_Indicator = 'N' OR [ReleaseStatus_Name] = 'Deployed')
		   AND (@RejectedOnly_Indicator = 'N' OR [BuildStatus_Name] = 'Rejected')
		   AND (@AlwaysRetainAfter_Date IS NULL OR [CreatedOn_Date] < @AlwaysRetainAfter_Date)
           AND EXISTS(
						        SELECT TOP 1 SEL.[Scope_Sequence]
								  FROM [BuildExecutions_Extended] BEX
							INNER JOIN [ScopedExecutionLogs] SEL
							        ON SEL.[Execution_Id] = BEX.[Execution_Id]
                                 WHERE B.[Build_Id] = BEX.[Build_Id]
            )
		 ORDER BY [CreatedOn_Date]

	END

END
GO

GRANT EXECUTE ON [RetentionPolicies_GetBuildsWithLogsToPurge] TO [BuildMasterUser_Role]